@@ -35,6 +35,7 @@ from thermo.heat_capacity import *
 from thermo.phase_change import *
 from thermo import ChemicalConstantsPackage, PropertyCorrelationsPackage
 from chemicals.exceptions import PhaseCountReducedError, TrivialSolutionError
+from chemicals import flash_wilson
 
 @pytest.mark.skip
 def test_minimize_gibbs_NP_transformed():
@@ -229,6 +230,41 @@ def test_dew_bubble_newton_zs():
     assert_allclose(comp, [0.5781248395738718, 0.3717955398333062, 0.05007962059282194])
     assert_allclose(iter_val, 390.91409227801205)
 
+def test_dew_bubble_newton_zs_other_solvers():
+    T, P = 506.5, 4118858.867178611
+    zs = [.3, .5, .2]
+    comp_guess = [0.3867045231954888, 0.47096784177875883, 0.14232763502575238]
+    eos_kwargs = {'Pcs': [22048320.0, 3025000.0, 4108000.0], 'Tcs': [647.14, 507.6, 591.75], 'omegas': [0.344, 0.2975, 0.257]}
+    HeatCapacityGases = [HeatCapacityGas(poly_fit=(50.0, 1000.0, [5.543665000518528e-22, -2.403756749600872e-18, 4.2166477594350336e-15, -3.7965208514613565e-12, 1.823547122838406e-09, -4.3747690853614695e-07, 5.437938301211039e-05, -0.003220061088723078, 33.32731489750759])),
+                         HeatCapacityGas(poly_fit=(200.0, 1000.0, [1.3740654453881647e-21, -8.344496203280677e-18, 2.2354782954548568e-14, -3.4659555330048226e-11, 3.410703030634579e-08, -2.1693611029230923e-05, 0.008373280796376588, -1.356180511425385, 175.67091124888998])),
+                         HeatCapacityGas(poly_fit=(50.0, 1000.0, [-9.48396765770823e-21, 4.444060985512694e-17, -8.628480671647472e-14, 8.883982004570444e-11, -5.0893293251198045e-08, 1.4947108372371731e-05, -0.0015271248410402886, 0.19186172941013854, 30.797883940134057]))]
+    
+    gas = CEOSGas(PRMIX, eos_kwargs, HeatCapacityGases=HeatCapacityGases, T=T, P=P, zs=zs)
+    liq = CEOSLiquid(PRMIX, eos_kwargs, HeatCapacityGases=HeatCapacityGases, T=T, P=P, zs=zs)
+    
+    # TVF-0
+    TVF0_lm = dew_bubble_newton_zs(P, T, zs, liq, gas, 
+                                comp_guess=comp_guess,
+                               iter_var='P', fixed_var='T', V_over_F=0, method='lm',
+                               maxiter=200, xtol=1E-9, debug=False)
+    TVF0_newton = dew_bubble_newton_zs(P, T, zs, liq, gas, 
+                                comp_guess=comp_guess,
+                               iter_var='P', fixed_var='T', V_over_F=0, method='newton',
+                               maxiter=200, xtol=1E-9, debug=False)
+    
+    TVF0_hybr = dew_bubble_newton_zs(P, T, zs, liq, gas, 
+                                comp_guess=comp_guess,
+                               iter_var='P', fixed_var='T', V_over_F=0, method='hybr',
+                               maxiter=200, xtol=1E-9, debug=False)
+    y_expect = [0.4007600877654008, 0.4650053034175482, 0.13423460881705107]
+    assert_close(TVF0_lm[0], TVF0_newton[0])
+    assert_close(TVF0_hybr[0], TVF0_newton[0])
+    assert_close(TVF0_newton[0], 3915539.2405)
+    assert_close1d(y_expect, TVF0_newton[1])
+    assert_close1d(y_expect, TVF0_hybr[1])
+    assert_close1d(y_expect, TVF0_newton[1])
+
+
 
 def test_dew_bubble_Michelsen_Mollerup_pure():
     # Only goal here is to check the trivial composition test does not
@@ -278,10 +314,10 @@ def test_stabiliy_iteration_Michelsen_zero_fraction():
     zs_test = [0.0, 0.966916481252204, 0.033083518747796005]
     kwargs = {'trial_phase': liq, 'zs_test': zs_test,
            'test_phase': gas, 'maxiter': 500, 'xtol': 5e-09}
-    sln_with_zero = stabiliy_iteration_Michelsen(**kwargs)[0:-1]
+    sln_with_zero = stability_iteration_Michelsen(**kwargs)[0:-1]
 
     kwargs['zs_test'] = [1e-13, 0.966916481252204-5e-14, 0.033083518747796005-5e-14]
-    sln_without_zero = stabiliy_iteration_Michelsen(**kwargs)[0:-1]
+    sln_without_zero = stability_iteration_Michelsen(**kwargs)[0:-1]
     assert_allclose(sln_with_zero[-2][1:], sln_without_zero[-2][1:], rtol=1e-5)
     assert_allclose(sln_with_zero[-1][1:], sln_without_zero[-1][1:], rtol=1e-5)
     assert_allclose(sln_with_zero[-3], sln_without_zero[-3], rtol=1e-5)
@@ -603,3 +639,73 @@ def test_flash_iapws95():
 
 
 
+def test_sequential_substitution_2P_functional_vs_FlashVL():
+    T, P = 300, 1.6e6
+    constants = ChemicalConstantsPackage(Tcs=[305.32, 469.7], Pcs=[4872000.0, 3370000.0],
+                                         omegas=[0.098, 0.251], Tms=[90.3, 143.15],
+                                         Tbs=[184.55, 309.21], CASs=['74-84-0', '109-66-0'],
+                                         names=['ethane', 'pentane'], MWs=[30.06904, 72.14878])
+    HeatCapacityGases = [HeatCapacityGas(poly_fit=(50.0, 1000.0, [7.115386645067898e-21, -3.2034776773408394e-17, 5.957592282542187e-14, -5.91169369931607e-11, 3.391209091071677e-08, -1.158730780040934e-05, 0.002409311277400987, -0.18906638711444712, 37.94602410497228])),
+                         HeatCapacityGas(poly_fit=(200.0, 1000.0, [7.537198394065234e-22, -4.946850205122326e-18, 1.4223747507170372e-14, -2.3451318313798008e-11, 2.4271676873997662e-08, -1.6055220805830093e-05, 0.006379734000450042, -1.0360272314628292, 141.84695243411866]))]
+    correlations = PropertyCorrelationsPackage(constants, HeatCapacityGases=HeatCapacityGases)
+    zs = [.5, .5]
+    eos_kwargs = {'Pcs': constants.Pcs, 'Tcs': constants.Tcs, 'omegas': constants.omegas}
+    _, _, VF, xs, ys = flash_wilson(zs=zs, Tcs=eos_kwargs['Tcs'], Pcs=eos_kwargs['Pcs'], omegas=eos_kwargs['omegas'], T=T, P=P)
+    
+    # There are a lot of specially-coded numbers
+    # so yes, it is necessary to loop through all the EOSs and check they are the same.
+    for obj in eos_mix_list:
+        if obj is IGMIX:
+            continue
+    
+        gas = CEOSGas(PRMIX, eos_kwargs, HeatCapacityGases=HeatCapacityGases, T=T, P=P, zs=zs)
+        liq = CEOSLiquid(PRMIX, eos_kwargs, HeatCapacityGases=HeatCapacityGases, T=T, P=P, zs=zs)
+        
+        flasher = FlashVL(constants, correlations, liquid=liq, gas=gas)
+        res_expect = flasher.flash(T=T, P=P, zs=zs)
+        VF_expect, xs_expect, ys_expect = res_expect.VF, res_expect.liquid0.zs, res_expect.gas.zs
+        
+    
+        VF_calc, xs_calc, ys_calc, niter, err = sequential_substitution_2P_functional(zs=zs, xs_guess=xs, ys_guess=ys,
+                                       liquid_args=liq.lnphis_args(), gas_args=gas.lnphis_args(),
+                                              maxiter=1000, tol=1E-20,
+                                           trivial_solution_tol=1e-5, V_over_F_guess=0.5)
+        assert_close(VF_calc, VF_expect, rtol=1e-6)
+        assert_close1d(xs_calc, xs_expect)
+        assert_close1d(ys_calc, ys_expect)
+        
+        
+    # Do a test with a mixed-EOS model
+    gas = CEOSGas(SRKMIX, eos_kwargs, HeatCapacityGases=HeatCapacityGases, T=T, P=P, zs=zs)
+    liq = CEOSLiquid(PRMIX, eos_kwargs, HeatCapacityGases=HeatCapacityGases, T=T, P=P, zs=zs)
+    
+    flasher = FlashVL(constants, correlations, liquid=liq, gas=gas)
+    res_expect = flasher.flash(T=T, P=P, zs=zs)
+    VF_expect, xs_expect, ys_expect = res_expect.VF, res_expect.liquid0.zs, res_expect.gas.zs
+    
+    VF_calc, xs_calc, ys_calc, niter, err = sequential_substitution_2P_functional(zs=zs, xs_guess=xs, ys_guess=ys,
+                                   liquid_args=liq.lnphis_args(), gas_args=gas.lnphis_args(),
+                                          maxiter=1000, tol=1E-20,
+                                       trivial_solution_tol=1e-5, V_over_F_guess=0.5)
+    assert_close(VF_calc, VF_expect, rtol=1e-6)
+    assert_close1d(xs_calc, xs_expect)
+    assert_close1d(ys_calc, ys_expect)
+    
+    # Do an IG gas phase
+    T, P = 300, 1.3e6
+    zs = [.5, .5]
+    
+    gas = CEOSGas(IGMIX, eos_kwargs, HeatCapacityGases=HeatCapacityGases, T=T, P=P, zs=zs)
+    liq = CEOSLiquid(PRMIX, eos_kwargs, HeatCapacityGases=HeatCapacityGases, T=T, P=P, zs=zs)
+    
+    flasher = FlashVL(constants, correlations, liquid=liq, gas=gas)
+    res_expect = flasher.flash(T=T, P=P, zs=zs)
+    VF_expect, xs_expect, ys_expect = res_expect.VF, res_expect.liquid0.zs, res_expect.gas.zs
+    
+    VF_calc, xs_calc, ys_calc, niter, err = sequential_substitution_2P_functional(zs=zs, xs_guess=xs, ys_guess=ys,
+                                   liquid_args=liq.lnphis_args(), gas_args=gas.lnphis_args(),
+                                          maxiter=1000, tol=1E-20,
+                                       trivial_solution_tol=1e-5, V_over_F_guess=0.5)
+    assert_close(VF_calc, VF_expect, rtol=1e-6)
+    assert_close1d(xs_calc, xs_expect)
+    assert_close1d(ys_calc, ys_expect)
\ No newline at end of file
