@@ -22,12 +22,12 @@ SOFTWARE.'''
 
 import pytest
 
-from fluids.numerics import assert_close, assert_close1d
+from fluids.numerics import assert_close, assert_close1d, linspace
 from thermo.phase_change import *
 from chemicals.miscdata import CRC_inorganic_data, CRC_organic_data
 from chemicals.identifiers import check_CAS
 from thermo.coolprop import has_CoolProp
-
+import chemicals
 from thermo.phase_change import COOLPROP, VDI_PPDS, CLAPEYRON, LIU, ALIBAKHSHI, MORGAN_KOBAYASHI, VELASCO, PITZER, RIEDEL, SIVARAMAN_MAGEE_KOBAYASHI, CHEN, CRC_HVAP_TB, DIPPR_PERRY_8E, VETERE, CRC_HVAP_298, VDI_TABULAR, GHARAGHEIZI_HVAP_298
 
 @pytest.mark.meta_T_dept
@@ -158,3 +158,64 @@ def test_EnthalpyVaporization_Watson_extrapolation():
 @pytest.mark.meta_T_dept
 def test_EnthalpySublimation_no_numpy():
     assert type(EnthalpySublimation(CASRN='1327-53-3').CRC_Hfus) is float
+
+@pytest.mark.meta_T_dept
+@pytest.mark.fitting
+def test_EnthalpyVaporization_fitting0():
+    ammonia_Ts_Hvaps = [195.41, 206.344, 217.277, 228.211, 239.145, 239.82, 250.078, 261.012, 271.946, 282.879, 293.813, 304.747, 315.681, 326.614, 337.548, 348.482, 359.415, 370.349, 381.283, 392.216, 403.15]
+    ammonia_Hvaps = [25286.1, 24832.3, 24359.1, 23866.9, 23354.6, 23322.3, 22820.1, 22259.6, 21667.7, 21037.4, 20359.5, 19622.7, 18812.8, 17912.4, 16899.8, 15747, 14416.3, 12852.3, 10958.8, 8510.62, 4311.94]
+    obj = EnthalpyVaporization(CASRN='7664-41-7', load_data=False)
+    
+    with pytest.raises(ValueError):
+        # Tc needs to be specified
+        obj.fit_data_to_model(Ts=ammonia_Ts_Hvaps, data=ammonia_Hvaps, model='DIPPR106',
+                              do_statistics=True, use_numba=False, fit_method='lm')
+        
+    fit, res = obj.fit_data_to_model(Ts=ammonia_Ts_Hvaps, data=ammonia_Hvaps, model='DIPPR106',
+                      do_statistics=True, use_numba=False, model_kwargs={'Tc': 405.400},
+                      fit_method='lm'
+                     )
+    assert res['MAE'] < 1e-5
+    
+@pytest.mark.fitting
+@pytest.mark.meta_T_dept
+def test_EnthalpyVaporization_fitting1_dippr_106():
+    check_CAS_fits = ['74-86-2', '108-05-4', '7440-37-1', '7440-59-7',
+                      '1333-74-0', '7664-39-3']
+    for CAS in check_CAS_fits:
+        obj = EnthalpyVaporization(CASRN=CAS)
+        Ts = linspace(obj.Perrys2_150_Tmin, obj.Perrys2_150_Tmax, 8)
+        props_calc = [obj.calculate(T, DIPPR_PERRY_8E) for T in Ts]
+        res, stats = obj.fit_data_to_model(Ts=Ts, data=props_calc, model='DIPPR106',
+                              do_statistics=True, use_numba=False, fit_method='lm', 
+                                           model_kwargs={'Tc': obj.Perrys2_150_coeffs[0]})
+        assert stats['MAE'] < 1e-7
+
+@pytest.mark.slow
+@pytest.mark.fuzz
+@pytest.mark.fitting
+@pytest.mark.meta_T_dept
+def test_EnthalpyVaporization_fitting2_dippr_106():
+
+    for i, CAS in enumerate(chemicals.phase_change.phase_change_data_VDI_PPDS_4.index):
+        obj = EnthalpyVaporization(CASRN=CAS)
+        Ts = linspace(obj.T_limits[VDI_PPDS][0], obj.T_limits[VDI_PPDS][1], 8)
+        props_calc = [obj.calculate(T, VDI_PPDS) for T in Ts]
+        res, stats = obj.fit_data_to_model(Ts=Ts, data=props_calc, model='PPDS12',
+                              do_statistics=True, use_numba=False, fit_method='lm', 
+                                           model_kwargs={'Tc': obj.VDI_PPDS_Tc})
+        assert stats['MAE'] < 1e-7
+
+@pytest.mark.slow
+@pytest.mark.fuzz
+@pytest.mark.fitting
+@pytest.mark.meta_T_dept
+def test_EnthalpyVaporization_fitting3_dippr_106_full():
+    for CAS in chemicals.phase_change.phase_change_data_Perrys2_150.index:
+        obj = EnthalpyVaporization(CASRN=CAS)
+        Ts = linspace(obj.Perrys2_150_Tmin, obj.Perrys2_150_Tmax, 8)
+        props_calc = [obj.calculate(T, DIPPR_PERRY_8E) for T in Ts]
+        res, stats = obj.fit_data_to_model(Ts=Ts, data=props_calc, model='DIPPR106',
+                              do_statistics=True, use_numba=False, fit_method='lm', 
+                                           model_kwargs={'Tc': obj.Perrys2_150_coeffs[0]})
+        assert stats['MAE'] < 1e-7
