@@ -22,22 +22,28 @@ SOFTWARE.'''
 
 from __future__ import division
 
-__all__ = ['alpha_Twu91_objf', 'alpha_Twu91_objfc', 'fit',
+__all__ = ['alpha_Twu91_objf', 'alpha_Twu91_objfc', 'fit_function',
            'Twu91_check_params', 'postproc_lmfit',
            'alpha_poly_objf', 'alpha_poly_objfc', 'poly_check_params',
-           'fit_cheb_poly', 'poly_fit_statistics', 'fit_cheb_poly_auto']
+           'fit_cheb_poly', 'poly_fit_statistics', 'fit_cheb_poly_auto',
+           'data_fit_statistics']
 
-from cmath import atanh as catanh
 from fluids.numerics import (chebval, brenth, third, sixth, roots_cubic,
                              roots_cubic_a1, numpy as np, newton,
-                             bisect, inf, polyder, chebder,
+                             bisect, inf, polyder, chebder, std, min_max_ratios,
                              trunc_exp, secant, linspace, logspace,
                              horner, horner_and_der2, horner_and_der3,
-                             is_poly_positive, is_poly_negative)
+                             is_poly_positive, is_poly_negative,
+                             max_abs_error, max_abs_rel_error, max_squared_error, 
+                             max_squared_rel_error, mean_abs_error, mean_abs_rel_error, 
+                             mean_squared_error, mean_squared_rel_error)
 from fluids.constants import R
-from numpy.polynomial.chebyshev import poly2cheb
-from numpy.polynomial.chebyshev import cheb2poly
-from numpy.polynomial.polynomial import Polynomial
+try:
+    from numpy.polynomial.chebyshev import poly2cheb
+    from numpy.polynomial.chebyshev import cheb2poly
+    from numpy.polynomial.polynomial import Polynomial
+except:
+    pass
 
 ChebTools = None
 def fit_cheb_poly(func, low, high, n,
@@ -148,7 +154,19 @@ def fit_cheb_poly(func, low, high, n,
         coeffs = horner(coeffs, my_poly).coef[::-1].tolist()
     return coeffs
 
+def data_fit_statistics(xs, actual_pts, calc_pts):
+    pts = len(xs)
+    ARDs = [0.0]*pts
+    for i in range(pts):
+        if actual_pts[i] != 0.0:
+            ARDs[i] = abs((calc_pts[i]-actual_pts[i])/actual_pts[i])
 
+    mae = sum(ARDs)/pts
+    err_std = std(ARDs)
+    min_ratio, max_ratio = min_max_ratios(actual_pts, calc_pts)
+    return mae, err_std, min_ratio, max_ratio
+
+    
 def poly_fit_statistics(func, coeffs, low, high, pts=200,
                         interpolation_property_inv=None,
                         interpolation_x=lambda x: x,
@@ -461,7 +479,7 @@ def postproc_lmfit(result):
     return result
 
 
-def fit(fun, x0=None, args=None, check_fun=None, debug=False,
+def fit_function(fun, x0=None, args=None, check_fun=None, debug=False,
         cons_meth=methods_cons_good, uncons_meth=methods_uncons_good):
     from lmfit import Parameter, Parameters, minimize
     best_result = None
