@@ -272,13 +272,13 @@ class HeatCapacityGas(TDependentProperty):
     custom_args = ('MW', 'similarity_variable')
 
     def __init__(self, CASRN='', MW=None, similarity_variable=None,
-                 extrapolation='linear', **kwargs):
+                 extrapolation='linear', iscyclic_aliphatic=False, **kwargs):
         self.CASRN = CASRN
         self.MW = MW
         self.similarity_variable = similarity_variable
+        self.iscyclic_aliphatic = iscyclic_aliphatic
         super(HeatCapacityGas, self).__init__(extrapolation, **kwargs)
 
-
     def load_all_methods(self, load_data=True):
         r'''Method which picks out coefficients for the specified chemical
         from the various dictionaries and DataFrames storing it. All data is
@@ -291,14 +291,12 @@ class HeatCapacityGas(TDependentProperty):
         to reset the parameters.
         '''
         methods = []
-        Tmins, Tmaxs = [], []
         self.T_limits = T_limits = {}
         if load_data:
             if self.CASRN in heat_capacity.TRC_gas_data.index:
                 methods.append(TRCIG)
                 self.TRCIG_Tmin, self.TRCIG_Tmax, a0, a1, a2, a3, a4, a5, a6, a7, _, _, _ = heat_capacity.TRC_gas_values[heat_capacity.TRC_gas_data.index.get_loc(self.CASRN)].tolist()
                 self.TRCIG_coefs = [a0, a1, a2, a3, a4, a5, a6, a7]
-                Tmins.append(self.TRCIG_Tmin); Tmaxs.append(self.TRCIG_Tmax)
                 T_limits[TRCIG] = (self.TRCIG_Tmin, self.TRCIG_Tmax)
             if self.CASRN in heat_capacity.Cp_data_Poling.index and not isnan(heat_capacity.Cp_data_Poling.at[self.CASRN, 'a0']):
                 POLING_Tmin, POLING_Tmax, a0, a1, a2, a3, a4, Cpg, Cpl = heat_capacity.Cp_values_Poling[heat_capacity.Cp_data_Poling.index.get_loc(self.CASRN)].tolist()
@@ -308,9 +306,7 @@ class HeatCapacityGas(TDependentProperty):
                 if isnan(POLING_Tmax):
                     POLING_Tmax = 1000.0
                 self.POLING_Tmin = POLING_Tmin
-                Tmins.append(POLING_Tmin)
                 self.POLING_Tmax = POLING_Tmax
-                Tmaxs.append(POLING_Tmax)
                 self.POLING_coefs = [a0, a1, a2, a3, a4]
                 T_limits[POLING_POLY] = (POLING_Tmin, POLING_Tmax)
             if self.CASRN in heat_capacity.Cp_data_Poling.index and not isnan(heat_capacity.Cp_data_Poling.at[self.CASRN, 'Cpg']):
@@ -332,21 +328,17 @@ class HeatCapacityGas(TDependentProperty):
                 self.VDI_Tmin = Ts[0]
                 self.VDI_Tmax = Ts[-1]
                 self.tabular_data[VDI_TABULAR] = (Ts, props)
-                Tmins.append(self.VDI_Tmin); Tmaxs.append(self.VDI_Tmax)
                 T_limits[VDI_TABULAR] = (self.VDI_Tmin, self.VDI_Tmax)
             if has_CoolProp() and self.CASRN in coolprop_dict:
                 methods.append(COOLPROP)
                 self.CP_f = coolprop_fluids[self.CASRN]
                 Tmin = max(self.CP_f.Tt, self.CP_f.Tmin)
                 Tmax = min(self.CP_f.Tc, self.CP_f.Tmax)
-                Tmins.append(Tmin); Tmaxs.append(Tmax)
                 T_limits[COOLPROP] = (Tmin, Tmax)
         if self.MW and self.similarity_variable:
             methods.append(LASTOVKA_SHAW)
             T_limits[LASTOVKA_SHAW] = (1e-3, 1e5)
         self.all_methods = set(methods)
-        if Tmins and Tmaxs:
-            self.Tmin, self.Tmax = min(Tmins), max(Tmaxs)
 
     @staticmethod
     def _method_indexes():
@@ -406,8 +398,7 @@ class HeatCapacityGas(TDependentProperty):
         elif method == CRCSTD:
             Cp = self.CRCSTD_constant
         elif method == LASTOVKA_SHAW:
-            Cp = Lastovka_Shaw(T, self.similarity_variable)
-            Cp = property_mass_to_molar(Cp, self.MW)
+            Cp = Lastovka_Shaw(T, self.similarity_variable, self.iscyclic_aliphatic, self.MW)
         else:
             return self._base_calculate(T, method)
         return Cp
@@ -455,16 +446,8 @@ class HeatCapacityGas(TDependentProperty):
         elif method == COOLPROP:
             if T <= self.CP_f.Tmin or T >= self.CP_f.Tmax:
                 return False
-        elif method == POLY_FIT:
-            validity = True
-        elif method in self.tabular_data:
-            # if tabular_extrapolation_permitted, good to go without checking
-            if not self.tabular_extrapolation_permitted:
-                Ts, properties = self.tabular_data[method]
-                if T < Ts[0] or T > Ts[-1]:
-                    validity = False
         else:
-            raise Exception('Method not valid')
+            return super(HeatCapacityGas, self).test_method_validity(T, method)
         return validity
 
     def calculate_integral(self, T1, T2, method):
@@ -507,9 +490,14 @@ class HeatCapacityGas(TDependentProperty):
         elif method == CRCSTD:
             return (T2 - T1)*self.CRCSTD_constant
         elif method == LASTOVKA_SHAW:
-            dH = (Lastovka_Shaw_integral(T2, self.similarity_variable)
-                    - Lastovka_Shaw_integral(T1, self.similarity_variable))
-            return property_mass_to_molar(dH, self.MW)
+            similarity_variable = self.similarity_variable
+            iscyclic_aliphatic = self.iscyclic_aliphatic
+            MW = self.MW
+            term_A = Lastovka_Shaw_term_A(similarity_variable, iscyclic_aliphatic)
+            return (
+                Lastovka_Shaw_integral(T2, similarity_variable, iscyclic_aliphatic, MW, term_A)
+                - Lastovka_Shaw_integral(T1, similarity_variable, iscyclic_aliphatic, MW, term_A)
+            )
         else:
             return super(HeatCapacityGas, self).calculate_integral(T1, T2, method)
 
@@ -555,9 +543,14 @@ class HeatCapacityGas(TDependentProperty):
             S1 = ((((0.25*E)*T1 + D/3.)*T1 + 0.5*C)*T1 + B)*T1
             return R*(S2-S1 + A*log(T2/T1))
         elif method == LASTOVKA_SHAW:
-            dS = (Lastovka_Shaw_integral_over_T(T2, self.similarity_variable)
-                 - Lastovka_Shaw_integral_over_T(T1, self.similarity_variable))
-            return property_mass_to_molar(dS, self.MW)
+            similarity_variable = self.similarity_variable
+            iscyclic_aliphatic = self.iscyclic_aliphatic
+            MW = self.MW
+            term_A = Lastovka_Shaw_term_A(similarity_variable, iscyclic_aliphatic)
+            return (
+                Lastovka_Shaw_integral_over_T(T2, similarity_variable, iscyclic_aliphatic, MW, term_A)
+                - Lastovka_Shaw_integral_over_T(T1, similarity_variable, iscyclic_aliphatic, MW, term_A)
+            )
         return super(HeatCapacityGas, self).calculate_integral_over_T(T1, T2, method)
 
 
@@ -817,7 +810,6 @@ class HeatCapacityLiquid(TDependentProperty):
         to reset the parameters.
         '''
         methods = []
-        Tmins, Tmaxs = [], []
         self.T_limits = T_limits = {}
         if load_data:
             if self.CASRN in heat_capacity.zabransky_dict_const_s:
@@ -866,14 +858,12 @@ class HeatCapacityLiquid(TDependentProperty):
                 self.VDI_Tmin = Ts[0]
                 self.VDI_Tmax = Ts[-1]
                 self.tabular_data[VDI_TABULAR] = (Ts, props)
-                Tmins.append(self.VDI_Tmin); Tmaxs.append(self.VDI_Tmax)
                 T_limits[VDI_TABULAR] = (self.VDI_Tmin, self.VDI_Tmax)
             if has_CoolProp() and self.CASRN in coolprop_dict:
                 methods.append(COOLPROP)
                 self.CP_f = coolprop_fluids[self.CASRN]
                 Tmin = max(self.CP_f.Tt, self.CP_f.Tmin)
                 Tmax = min(self.CP_f.Tc*.9999, self.CP_f.Tmax)
-                Tmins.append(Tmin); Tmaxs.append(Tmax)
                 T_limits[COOLPROP] = (Tmin, Tmax)
         if self.Tc and self.omega:
             methods.extend([ROWLINSON_POLING, ROWLINSON_BONDI])
@@ -882,12 +872,8 @@ class HeatCapacityLiquid(TDependentProperty):
             T_limits[ROWLINSON_BONDI] = limits_Tc
         if self.MW and self.similarity_variable:
             methods.append(DADGOSTAR_SHAW)
-            T_limits[DADGOSTAR_SHAW] = (1e-3, self.Tc if self.Tc is not None else 10000)
+            T_limits[DADGOSTAR_SHAW] = (1e-3, 10000. if self.Tc is None else self.Tc)
         self.all_methods = set(methods)
-        if Tmins and Tmaxs:
-            # TODO: More Tmin, Tmax ranges
-            self.Tmin, self.Tmax = min(Tmins), max(Tmaxs)
-
 
     def calculate(self, T, method):
         r'''Method to calculate heat capacity of a liquid at temperature `T`
@@ -1003,16 +989,8 @@ class HeatCapacityLiquid(TDependentProperty):
         elif method in [ROWLINSON_POLING, ROWLINSON_BONDI]:
             if self.Tc and T > self.Tc:
                 return False
-        elif method == POLY_FIT:
-            validity = True
-        elif method in self.tabular_data:
-            # if tabular_extrapolation_permitted, good to go without checking
-            if not self.tabular_extrapolation_permitted:
-                Ts, properties = self.tabular_data[method]
-                if T < Ts[0] or T > Ts[-1]:
-                    validity = False
         else:
-            raise Exception('Method not valid')
+            return super(HeatCapacityLiquid, self).test_method_validity(T, method)
         return validity
 
     def calculate_integral(self, T1, T2, method):
@@ -1257,7 +1235,6 @@ class HeatCapacitySolid(TDependentProperty):
         to reset the parameters.
         '''
         methods = []
-        Tmins, Tmaxs = [], []
         self.T_limits = T_limits = {}
         if load_data:
             if self.CASRN and self.CASRN in heat_capacity.Cp_dict_PerryI and 'c' in heat_capacity.Cp_dict_PerryI[self.CASRN]:
@@ -1268,7 +1245,6 @@ class HeatCapacitySolid(TDependentProperty):
                 self.PERRY151_quad = heat_capacity.Cp_dict_PerryI[self.CASRN]['c']['Quad']
                 self.PERRY151_quadinv = heat_capacity.Cp_dict_PerryI[self.CASRN]['c']['Quadinv']
                 methods.append(PERRY151)
-                Tmins.append(self.PERRY151_Tmin); Tmaxs.append(self.PERRY151_Tmax)
                 T_limits[PERRY151] = (self.PERRY151_Tmin, self.PERRY151_Tmax)
             if self.CASRN in heat_capacity.CRC_standard_data.index and not isnan(heat_capacity.CRC_standard_data.at[self.CASRN, 'Cps']):
                 self.CRCSTD_Cp = float(heat_capacity.CRC_standard_data.at[self.CASRN, 'Cps'])
@@ -1276,13 +1252,9 @@ class HeatCapacitySolid(TDependentProperty):
                 T_limits[CRCSTD] = (298.15, 298.15)
         if self.MW and self.similarity_variable:
             methods.append(LASTOVKA_S)
-            Tmins.append(1.0); Tmaxs.append(10000)
             T_limits[LASTOVKA_S] = (1.0, 1e4)
             # Works above roughly 1 K up to 10K.
         self.all_methods = set(methods)
-        if Tmins and Tmaxs:
-            self.Tmin, self.Tmax = min(Tmins), max(Tmaxs)
-
 
     def calculate(self, T, method):
         r'''Method to calculate heat capacity of a solid at temperature `T`
@@ -1357,16 +1329,8 @@ class HeatCapacitySolid(TDependentProperty):
         elif method == LASTOVKA_S:
             if T > 10000 or T < 0:
                 validity = False
-        elif method in self.tabular_data:
-            # if tabular_extrapolation_permitted, good to go without checking
-            if not self.tabular_extrapolation_permitted:
-                Ts, properties = self.tabular_data[method]
-                if T < Ts[0] or T > Ts[-1]:
-                    validity = False
-        elif method == POLY_FIT:
-            validity = True
         else:
-            raise Exception('Method not valid')
+            return super(HeatCapacitySolid, self).test_method_validity(T, method)
         return validity
 
     def calculate_integral(self, T1, T2, method):
